variable "subscription" {
  description = "The ID of your Azure subscription."
}
 
variable "storage_account_name" {
  description = "Name of your storage account. Should be globally unique and only contain alphanumeric characters."
}
 
variable "resource_group_name" {
  description = "Name of the resource group you plan on deploying the resources."
  default     = "nevis-cluster"
}
 
variable "location" {
  description = "Location where to deploy the resources."
  default     = "West Europe"
}
 
provider "azurerm" {
  subscription_id = "${var.subscription}"
}
 
resource "azurerm_resource_group" "rg" {
  name     = "${var.resource_group_name}"
  location = "${var.location}"
}
 
resource "azurerm_storage_account" "terraform" {
  name                      = "${var.storage_account_name}"
  resource_group_name       = "${azurerm_resource_group.rg.name}"
  location                  = "${azurerm_resource_group.rg.location}"
  account_tier              = "Standard"
  account_replication_type  = "LRS"
  enable_https_traffic_only = true
}
 
resource "azurerm_storage_container" "terraform" {
  name                  = "terraform-state"
  resource_group_name   = "${azurerm_storage_account.terraform.resource_group_name}"
  storage_account_name  = "${azurerm_storage_account.terraform.name}"
  container_access_type = "private"
}
 
output "storage-account-name" {
  value = "${azurerm_storage_account.terraform.name}"
}
